@@ -33,9 +33,6 @@
 #include <libmate-desktop/mate-aboutdialog.h>
 #include <libmate-desktop/mate-colorbutton.h>
 
-#define MATE_DESKTOP_USE_UNSTABLE_API
-#include <libmate-desktop/mate-desktop-utils.h>
-
 #include "backend.h"
 
  /* Icons for the interfaces */
@@ -121,22 +118,6 @@ update_tooltip(MateNetspeedApplet* applet);
 static void
 device_change_cb(GtkComboBox *combo, MateNetspeedApplet *applet);
 
-static gboolean
-open_uri (GtkWidget *parent, const char *url, GError **error)
-{
-	gboolean ret;
-	char *cmdline;
-	GdkScreen *screen;
-
-	screen = gtk_widget_get_screen (parent);
-	cmdline = g_strconcat ("xdg-open ", url, NULL);
-
-	ret = mate_gdk_spawn_command_line_on_screen (screen, cmdline, error);
-	g_free (cmdline);
-
-	return ret;
-}
-
 /* Adds a Pango markup "size" to a bytestring
  */
 static void
@@ -455,10 +436,10 @@ bytes_to_string(double bytes, gboolean per_sec, gboolean bits, gboolean shortene
 			if (shortened) {
 				unit = bits ? /* translators: megabits (short) */ N_("m") : /* translators: Megabytes (short) */ N_("M");
 			} else {
-				unit = bits ? N_("mb/s") : N_("MiB/s");
+				unit = bits ? N_("Mb/s") : N_("MiB/s");
 			}
 		else
-			unit = bits ? N_("mb")   : N_("MiB");
+			unit = bits ? N_("Mb")   : N_("MiB");
 	}
 
 	return g_strdup_printf(format, bytes, gettext(unit));
@@ -782,17 +763,20 @@ timeout_function(MateNetspeedApplet *applet)
 static void
 display_help (GtkWidget *dialog, const gchar *section)
 {
+	GdkScreen *screen;
 	GError *error = NULL;
 	gboolean ret;
 	char *uri;
 
 	if (section)
-		uri = g_strdup_printf ("http://wiki.mate-desktop.org/docs:mate-netspeed#%s", section);
+		uri = g_strdup_printf ("help:mate-netspeed-applet/%s", section);
 	else
-		uri = g_strdup ("http://wiki.mate-desktop.org/docs:mate-netspeed");
+		uri = g_strdup ("help:mate-netspeed-applet");
 
-	ret = open_uri (dialog, uri, &error);
+	screen = gtk_widget_get_screen (dialog);
+	ret = gtk_show_uri (screen, uri, gtk_get_current_event_time (), &error);
 	g_free (uri);
+
 	if (ret == FALSE) {
 		GtkWidget *error_dialog = gtk_message_dialog_new (NULL,
 								  GTK_DIALOG_MODAL,
@@ -1172,7 +1156,7 @@ info_response_cb (GtkDialog *dialog, gint id, MateNetspeedApplet *applet)
 {
   
 	if(id == GTK_RESPONSE_HELP){
-		display_help (GTK_WIDGET (dialog), "mate_netspeed_applet-details");
+		display_help (GTK_WIDGET (dialog), "netspeed_applet-details");
 		return;
 	}
 	
@@ -1436,7 +1420,6 @@ applet_button_press(GtkWidget *widget, GdkEventButton *event, MateNetspeedApplet
 			applet->connect_dialog = gtk_message_dialog_new(NULL, 
 					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
-					"%s",
 					question,
 					applet->devinfo.name);
 			response = gtk_dialog_run(GTK_DIALOG(applet->connect_dialog));
